==> toughpad-0.1.1.tar.gz: lib/toughpad.dart <==
import 'dart:async';
import 'package:rxdart/rxdart.dart';
import 'package:flutter/services.dart';

class Toughpad {
  static final hardwareExists = new BehaviorSubject<bool>.seeded(false);
  static const MethodChannel _channel = const MethodChannel('barcode');
  static final readBarcodes = new BehaviorSubject<String>.seeded("");
  static const BasicMessageChannel<String> _readBarcodesChannel = BasicMessageChannel<String>('readBarcodes', StringCodec());

  static final buttonEvents = new BehaviorSubject<String>.seeded("");
  static const BasicMessageChannel<String> _hwButtonsChannel = BasicMessageChannel<String>('buttonEvents', StringCodec());

  static Future<String> startBarcodeScan() async {
    String result = "";
    if (await hardwareExists.first) {
      result = await _channel.invokeMethod('startBarcodeScan');
    }
    return result;
  }

  static Future<String> stopBarcodeScan() async {
    String result = "";
    if (await hardwareExists.first) {
      result = await _channel.invokeMethod('stopBarcodeScan');
    }
    return result;
  }

  static Future<bool> checkHardware() async {
    final String result = await _channel.invokeMethod('checkHardware');
    return result=="1";
  }

  static Future<void> init() async {
    _readBarcodesChannel.setMessageHandler((String message) async {
      readBarcodes.add(message);
//      print('Received: $message');
      return '';
    });

    _hwButtonsChannel.setMessageHandler((String message) async {
      buttonEvents.add(message);
//      print('Received: $message');
      return '';
    });

    hardwareExists.add(await checkHardware());
  }
}

==> toughpad-1.0.0.tar.gz: lib/toughpad.dart <==
import 'dart:async';
import 'package:rxdart/rxdart.dart';
import 'package:flutter/services.dart';

class Toughpad {
  static final hardwareExists = new BehaviorSubject<bool>.seeded(false);
  static const MethodChannel _channel = const MethodChannel('barcode');
  static final readBarcodes = new BehaviorSubject<String>.seeded("");
  static const BasicMessageChannel<String> _readBarcodesChannel =
      BasicMessageChannel<String>('readBarcodes', StringCodec());

  static final buttonEvents = new BehaviorSubject<String>.seeded("");
  static const BasicMessageChannel<String> _hwButtonsChannel =
      BasicMessageChannel<String>('buttonEvents', StringCodec());

  static Future<String> startBarcodeScan() async {
    String result = "";
    if (await hardwareExists.first) {
      result = await _channel.invokeMethod('startBarcodeScan');
    }
    return result;
  }

  static Future<String> stopBarcodeScan() async {
    String result = "";
    if (await hardwareExists.first) {
      result = await _channel.invokeMethod('stopBarcodeScan');
    }
    return result;
  }

  static Future<bool> checkHardware() async {
    final String result = await _channel.invokeMethod('checkHardware');
    return result == "1";
  }

  static Future<void> init() async {
    _readBarcodesChannel.setMessageHandler((String message) async {
      readBarcodes.add(message);
      return '';
    });

    _hwButtonsChannel.setMessageHandler((String message) async {
      buttonEvents.add(message);
      return '';
    });

    hardwareExists.add(await checkHardware());
  }
}
